Create-Join TestCase

Create chat and Join to them
setSpeed | 400 |
open | / |
waitForElementPresent | //button[@id='create_chat'] |
clickAndWait | //button[@id='create_chat'] |
echo |  | Test chat body
verifyElementPresent | //main/div[@id='chat'] |
verifyElementPresent | //div[@id='chat-header'] |
verifyElementPresent | //img[@id='chat-close'] |
echo |  | Test welcome message
verifyElementPresent | //div[@class='message system'] |
verifyText | css=div.msg-text | glob:*Please send code:*
echo |  | Test sending
verifyElementPresent | //textarea[@id='id_chat_type'] |
verifyElementPresent | //button[@class='btn btn-green btn-grey'] |
echo |  | Join chat
storeEval | window.document.getElementsByClassName('message system')[0].getElementsByTagName('mark')[0].innerHTML | chatToken
echo | Chat Token: ${chatToken} |
open | / |
waitForElementPresent | //button[@id="join_chat"] |
type | //input[@id='id_chat_token'] | ${chatToken}
clickAndWait | //button[@id='join_chat'] |
verifyText | //div[@class='msg-text'] | glob:*Chat is ready to use*
verifyElementPresent | //button[@class='btn btn-green'] |